@@ -18,21 +18,22 @@ from mergedeep import merge
 @click.option('-r', '--replicas', default="{}")
 @click.option('-s', '--secrets', default="{}")
 @click.option('-e', '--service-params', default="{}")
+@click.option('--services', default=[])
 @click.option('-s', '--show-progress', default=False, is_flag=True)
 @click.argument('instance-name', required=False)
 def apply(directory, config_file, params, tags, secrets,
-          service_params, replicas, instance_name, show_progress):
+          service_params, replicas, services, instance_name, show_progress):
     stackl_context = StacklContext()
     if instance_name is None:
         upload_files(directory, stackl_context)
     else:
         apply_stack_instance(config_file, params, tags, secrets,
-                             service_params, replicas, stackl_context,
+                             service_params, replicas, services, stackl_context,
                              instance_name, show_progress)
 
 
 def apply_stack_instance(config_file, params, tags, secrets, service_params,
-                         replicas, stackl_context, instance_name, show_progress):
+                         replicas, services, stackl_context, instance_name, show_progress):
     final_params = {}
     for item in params:
         final_params = {**final_params, **json.loads(item)}
@@ -50,6 +51,8 @@ def apply_stack_instance(config_file, params, tags, secrets, service_params,
         secrets = {**config_doc['secrets'], **secrets}
     if "tags" in config_doc:
         tags = {**config_doc['tags'], **tags}
+    if "services" in config_doc:
+        services = config_doc['services']
     invocation = stackl_client.StackInstanceInvocation(
         stack_instance_name=instance_name,
         stack_infrastructure_template=config_doc[
@@ -59,6 +62,7 @@ def apply_stack_instance(config_file, params, tags, secrets, service_params,
         replicas=replicas,
         service_params=service_params,
         secrets=secrets,
+        services=services,
         tags=tags)
     try:
         stackl_context.stack_instances_api.get_stack_instance(instance_name)
